Class: Google::Apis::DomainsV1beta1::CloudDomainsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DomainsV1beta1::CloudDomainsService
- Defined in:
- lib/google/apis/domains_v1beta1/service.rb
Overview
Cloud Domains API
Enables management and configuration of domain names.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://domains.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#configure_registration_contact_settings(registration, configure_contact_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a
Registration's contact settings. -
#configure_registration_dns_settings(registration, configure_dns_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a
Registration's DNS settings. -
#configure_registration_management_settings(registration, configure_management_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a
Registration's management settings. -
#delete_project_location_registration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deletes a
Registrationresource. -
#export_registration(name, export_registration_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation Exports a
Registrationresource, such that it is no longer managed by Cloud Domains. -
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_registration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Registration
Gets the details of a
Registrationresource. -
#get_project_location_registration_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Policy
Gets the access control policy for a resource.
-
#import_registration_domain(parent, import_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation Imports a domain name from Google Domains for use in Cloud Domains.
-
#initialize ⇒ CloudDomainsService
constructor
A new instance of CloudDomainsService.
-
#initiate_registration_push_transfer(registration, initiate_push_transfer_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Initiates the
Push Transferprocess to transfer the domain to another registrar. -
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_registrations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListRegistrationsResponse
Lists the
Registrationresources in a project. -
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_registration(name, registration_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates select fields of a
Registrationresource, notablylabels. -
#register_registration_domain(parent, register_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Registers a new domain name and creates a corresponding
Registrationresource. -
#renew_registration_domain(registration, renew_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Renews a recently expired domain.
-
#reset_registration_authorization_code(registration, reset_authorization_code_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::AuthorizationCode
Resets the authorization code of the
Registrationto a new random string. -
#retrieve_project_location_registration_authorization_code(registration, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::AuthorizationCode
Gets the authorization code of the
Registrationfor the purpose of transferring the domain to another registrar. -
#retrieve_project_location_registration_google_domains_dns_records(registration, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsDnsRecordsResponse
Lists the DNS records from the Google Domains DNS zone for domains that use the deprecated
google_domains_dnsin theRegistration'sdns_settings. -
#retrieve_project_location_registration_google_domains_forwarding_config(registration, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsForwardingConfigResponse
Lists the deprecated domain and email forwarding configurations you set up in the deprecated Google Domains UI.
-
#retrieve_project_location_registration_importable_domains(location, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveImportableDomainsResponse
Deprecated: For more information, see Cloud Domains feature deprecation Lists domain names from Google Domains that can be imported to Cloud Domains using the
ImportDomainmethod. -
#retrieve_project_location_registration_register_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveRegisterParametersResponse
Gets parameters needed to register a new domain name, including price and up- to-date availability.
-
#retrieve_project_location_registration_transfer_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveTransferParametersResponse
Deprecated: For more information, see Cloud Domains feature deprecation Gets parameters needed to transfer a domain name from another registrar to Cloud Domains.
-
#search_project_location_registration_domains(location, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::SearchDomainsResponse
Searches for available domain names similar to the provided query.
-
#set_registration_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Policy
Sets the access control policy on the specified resource.
-
#test_registration_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#transfer_registration_domain(parent, transfer_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation Transfers a domain name from another registrar to Cloud Domains.
Constructor Details
#initialize ⇒ CloudDomainsService
Returns a new instance of CloudDomainsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-domains_v1beta1', client_version: Google::Apis::DomainsV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#configure_registration_contact_settings(registration, configure_contact_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a Registration's contact settings. Some changes require confirmation
by the domain's registrant contact . Caution: Please consider carefully any
changes to contact privacy settings when changing from REDACTED_CONTACT_DATA
to PUBLIC_CONTACT_DATA. There may be a delay in reflecting updates you make
to registrant contact information such that any changes you make to contact
privacy (including from REDACTED_CONTACT_DATA to PUBLIC_CONTACT_DATA) will
be applied without delay but changes to registrant contact information may
take a limited time to be publicized. This means that changes to contact
privacy from REDACTED_CONTACT_DATA to PUBLIC_CONTACT_DATA may make the
previous registrant contact data public until the modified registrant contact
details are published.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 252 def configure_registration_contact_settings(registration, configure_contact_settings_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:configureContactSettings', ) command.request_representation = Google::Apis::DomainsV1beta1::ConfigureContactSettingsRequest::Representation command.request_object = configure_contact_settings_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#configure_registration_dns_settings(registration, configure_dns_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a Registration's DNS settings.
286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 286 def configure_registration_dns_settings(registration, configure_dns_settings_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:configureDnsSettings', ) command.request_representation = Google::Apis::DomainsV1beta1::ConfigureDnsSettingsRequest::Representation command.request_object = configure_dns_settings_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#configure_registration_management_settings(registration, configure_management_settings_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates a Registration's management settings.
320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 320 def configure_registration_management_settings(registration, configure_management_settings_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:configureManagementSettings', ) command.request_representation = Google::Apis::DomainsV1beta1::ConfigureManagementSettingsRequest::Representation command.request_object = configure_management_settings_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_registration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deletes a Registration resource. This method works on any Registration
resource using Subscription or Commitment billing, provided that the resource was created at least 1 day in the past.
When an active registration is successfully deleted, you can continue to use
the domain in Google Domains until it expires. The
calling user becomes the domain's sole owner in Google Domains, and
permissions for the domain are subsequently managed there. The domain does not
renew automatically unless the new owner sets up billing in Google Domains.
After January 2024 you will only be able to delete Registration resources
when state is one of: EXPORTED, EXPIRED,REGISTRATION_FAILED or
TRANSFER_FAILED. See Cloud Domains feature deprecation for more details.
364 365 366 367 368 369 370 371 372 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 364 def delete_project_location_registration(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_registration(name, export_registration_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation
Exports a Registration resource, such that it is no longer managed by Cloud
Domains. When an active domain is successfully exported, you can continue to
use the domain in Google Domains until it expires.
The calling user becomes the domain's sole owner in Google Domains, and
permissions for the domain are subsequently managed there. The domain does not
renew automatically unless the new owner sets up billing in Google Domains.
403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 403 def export_registration(name, export_registration_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:export', ) command.request_representation = Google::Apis::DomainsV1beta1::ExportRegistrationRequest::Representation command.request_object = export_registration_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DomainsV1beta1::Location::Representation command.response_class = Google::Apis::DomainsV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 161 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_registration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Registration
Gets the details of a Registration resource.
436 437 438 439 440 441 442 443 444 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 436 def get_project_location_registration(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DomainsV1beta1::Registration::Representation command.response_class = Google::Apis::DomainsV1beta1::Registration command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_registration_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
480 481 482 483 484 485 486 487 488 489 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 480 def get_project_location_registration_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::DomainsV1beta1::Policy::Representation command.response_class = Google::Apis::DomainsV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_registration_domain(parent, import_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation
Imports a domain name from Google Domains for use
in Cloud Domains. To transfer a domain from another registrar, use the
TransferDomain method instead. Since individual users can own domains in
Google Domains, the calling user must have ownership permission on the domain.
518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 518 def import_registration_domain(parent, import_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/registrations:import', ) command.request_representation = Google::Apis::DomainsV1beta1::ImportDomainRequest::Representation command.request_object = import_domain_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#initiate_registration_push_transfer(registration, initiate_push_transfer_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Initiates the Push Transfer process to transfer the domain to another
registrar. The process might complete instantly or might require confirmation
or additional work. Check the emails sent to the email address of the
registrant. The process is aborted after a timeout if it's not completed. This
method is only supported for domains that have the REQUIRE_PUSH_TRANSFER
property in the list of domain_properties. The domain must also be unlocked
before it can be transferred to a different registrar. For more information,
see Transfer a registered domain to another registrar.
560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 560 def initiate_registration_push_transfer(registration, initiate_push_transfer_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:initiatePushTransfer', ) command.request_representation = Google::Apis::DomainsV1beta1::InitiatePushTransferRequest::Representation command.request_object = initiate_push_transfer_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 206 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::DomainsV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_registrations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListRegistrationsResponse
Lists the Registration resources in a project.
610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 610 def list_project_location_registrations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/registrations', ) command.response_representation = Google::Apis::DomainsV1beta1::ListRegistrationsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::ListRegistrationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::DomainsV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_registration(name, registration_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Updates select fields of a Registration resource, notably labels. To
update other fields, use the appropriate custom update method: * To update
management settings, see ConfigureManagementSettings * To update DNS
configuration, see ConfigureDnsSettings * To update contact information, see
ConfigureContactSettings
653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 653 def patch_project_location_registration(name, registration_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::DomainsV1beta1::Registration::Representation command.request_object = registration_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#register_registration_domain(parent, register_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Registers a new domain name and creates a corresponding Registration
resource. Call RetrieveRegisterParameters first to check availability of the
domain name and determine parameters like price that are needed to build a
call to this method. A successful call creates a Registration resource in
state REGISTRATION_PENDING, which resolves to ACTIVE within 1-2 minutes,
indicating that the domain was successfully registered. If the resource ends
up in state REGISTRATION_FAILED, it indicates that the domain was not
registered successfully, and you can safely delete the resource and retry
registration.
696 697 698 699 700 701 702 703 704 705 706 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 696 def register_registration_domain(parent, register_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/registrations:register', ) command.request_representation = Google::Apis::DomainsV1beta1::RegisterDomainRequest::Representation command.request_object = register_domain_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#renew_registration_domain(registration, renew_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Renews a recently expired domain. This method can only be called on domains
that expired in the previous 30 days. After the renewal, the new expiration
time of the domain is one year after the old expiration time and you are
charged a yearly_price for the renewal.
733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 733 def renew_registration_domain(registration, renew_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:renewDomain', ) command.request_representation = Google::Apis::DomainsV1beta1::RenewDomainRequest::Representation command.request_object = renew_domain_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reset_registration_authorization_code(registration, reset_authorization_code_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::AuthorizationCode
Resets the authorization code of the Registration to a new random string.
You can call this method only after 60 days have elapsed since the initial
domain registration. Domains that have the REQUIRE_PUSH_TRANSFER property in
the list of domain_properties don't support authorization codes and must use
the InitiatePushTransfer method to initiate the process to transfer the
domain to a different registrar.
772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 772 def (registration, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+registration}:resetAuthorizationCode', ) command.request_representation = Google::Apis::DomainsV1beta1::ResetAuthorizationCodeRequest::Representation command.request_object = command.response_representation = Google::Apis::DomainsV1beta1::AuthorizationCode::Representation command.response_class = Google::Apis::DomainsV1beta1::AuthorizationCode command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_authorization_code(registration, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::AuthorizationCode
Gets the authorization code of the Registration for the purpose of
transferring the domain to another registrar. You can call this method only
after 60 days have elapsed since the initial domain registration. Domains that
have the REQUIRE_PUSH_TRANSFER property in the list of domain_properties
don't support authorization codes and must use the InitiatePushTransfer
method to initiate the process to transfer the domain to a different registrar.
810 811 812 813 814 815 816 817 818 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 810 def (registration, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+registration}:retrieveAuthorizationCode', ) command.response_representation = Google::Apis::DomainsV1beta1::AuthorizationCode::Representation command.response_class = Google::Apis::DomainsV1beta1::AuthorizationCode command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_google_domains_dns_records(registration, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsDnsRecordsResponse
Lists the DNS records from the Google Domains DNS zone for domains that use
the deprecated google_domains_dns in the Registration's dns_settings.
848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 848 def retrieve_project_location_registration_google_domains_dns_records(registration, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+registration}:retrieveGoogleDomainsDnsRecords', ) command.response_representation = Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsDnsRecordsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsDnsRecordsResponse command.params['registration'] = registration unless registration.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_google_domains_forwarding_config(registration, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsForwardingConfigResponse
Lists the deprecated domain and email forwarding configurations you set up in
the deprecated Google Domains UI. The configuration is present only for
domains with the google_domains_redirects_data_available set to true in
the Registration's dns_settings. A forwarding configuration might not work
correctly if required DNS records are not present in the domain's
authoritative DNS Zone.
887 888 889 890 891 892 893 894 895 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 887 def retrieve_project_location_registration_google_domains_forwarding_config(registration, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+registration}:retrieveGoogleDomainsForwardingConfig', ) command.response_representation = Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsForwardingConfigResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::RetrieveGoogleDomainsForwardingConfigResponse command.params['registration'] = registration unless registration.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_importable_domains(location, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveImportableDomainsResponse
Deprecated: For more information, see Cloud Domains feature deprecation Lists
domain names from Google Domains that can be
imported to Cloud Domains using the ImportDomain method. Since individual
users can own domains in Google Domains, the list of domains returned depends
on the individual user making the call. Domains already managed by Cloud
Domains are not returned.
928 929 930 931 932 933 934 935 936 937 938 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 928 def retrieve_project_location_registration_importable_domains(location, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+location}/registrations:retrieveImportableDomains', ) command.response_representation = Google::Apis::DomainsV1beta1::RetrieveImportableDomainsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::RetrieveImportableDomainsResponse command.params['location'] = location unless location.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_register_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveRegisterParametersResponse
Gets parameters needed to register a new domain name, including price and up-
to-date availability. Use the returned values to call RegisterDomain.
964 965 966 967 968 969 970 971 972 973 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 964 def retrieve_project_location_registration_register_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+location}/registrations:retrieveRegisterParameters', ) command.response_representation = Google::Apis::DomainsV1beta1::RetrieveRegisterParametersResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::RetrieveRegisterParametersResponse command.params['location'] = location unless location.nil? command.query['domainName'] = domain_name unless domain_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_location_registration_transfer_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::RetrieveTransferParametersResponse
Deprecated: For more information, see Cloud Domains feature deprecation Gets
parameters needed to transfer a domain name from another registrar to Cloud
Domains. For domains already managed by Google Domains, use ImportDomain instead. Use the returned values to call
TransferDomain.
1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 1003 def retrieve_project_location_registration_transfer_parameters(location, domain_name: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+location}/registrations:retrieveTransferParameters', ) command.response_representation = Google::Apis::DomainsV1beta1::RetrieveTransferParametersResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::RetrieveTransferParametersResponse command.params['location'] = location unless location.nil? command.query['domainName'] = domain_name unless domain_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_registration_domains(location, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::SearchDomainsResponse
Searches for available domain names similar to the provided query.
Availability results from this method are approximate; call
RetrieveRegisterParameters on a domain before registering to confirm
availability.
1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 1039 def search_project_location_registration_domains(location, query: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+location}/registrations:searchDomains', ) command.response_representation = Google::Apis::DomainsV1beta1::SearchDomainsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::SearchDomainsResponse command.params['location'] = location unless location.nil? command.query['query'] = query unless query.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_registration_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 1075 def set_registration_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::DomainsV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::DomainsV1beta1::Policy::Representation command.response_class = Google::Apis::DomainsV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_registration_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 1114 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::DomainsV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::DomainsV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::DomainsV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#transfer_registration_domain(parent, transfer_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DomainsV1beta1::Operation
Deprecated: For more information, see Cloud Domains feature deprecation
Transfers a domain name from another registrar to Cloud Domains. For domains
already managed by Google Domains, use
ImportDomain instead. Before calling this method, go to the domain's current
registrar to unlock the domain for transfer and retrieve the domain's transfer
authorization code. Then call RetrieveTransferParameters to confirm that the
domain is unlocked and to get values needed to build a call to this method. A
successful call creates a Registration resource in state TRANSFER_PENDING.
It can take several days to complete the transfer process. The registrant can
often speed up this process by approving the transfer through the current
registrar, either by clicking a link in an email from the registrar or by
visiting the registrar's website. A few minutes after transfer approval, the
resource transitions to state ACTIVE, indicating that the transfer was
successful. If the transfer is rejected or the request expires without being
approved, the resource can end up in state TRANSFER_FAILED. If transfer
fails, you can safely delete the resource and retry the transfer.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 |
# File 'lib/google/apis/domains_v1beta1/service.rb', line 1164 def transfer_registration_domain(parent, transfer_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/registrations:transfer', ) command.request_representation = Google::Apis::DomainsV1beta1::TransferDomainRequest::Representation command.request_object = transfer_domain_request_object command.response_representation = Google::Apis::DomainsV1beta1::Operation::Representation command.response_class = Google::Apis::DomainsV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |