Class: Google::Apis::DomainsV1beta1::ConfigureManagementSettingsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb

Overview

Request for the ConfigureManagementSettings method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigureManagementSettingsRequest

Returns a new instance of ConfigureManagementSettingsRequest.



323
324
325
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_settingsGoogle::Apis::DomainsV1beta1::ManagementSettings

Defines renewal, billing, and transfer settings for a Registration. Corresponds to the JSON property managementSettings



307
308
309
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 307

def management_settings
  @management_settings
end

#update_maskString

Required. The field mask describing which fields to update as a comma- separated list. For example, if only the transfer lock is being updated, the update_mask is "transfer_lock_state". Corresponds to the JSON property updateMask

Returns:

  • (String)


314
315
316
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 314

def update_mask
  @update_mask
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validates the request without actually updating the management settings. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


320
321
322
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 320

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



328
329
330
331
332
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 328

def update!(**args)
  @management_settings = args[:management_settings] if args.key?(:management_settings)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end