Class: Google::Apis::DomainsV1beta1::CustomDns
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::CustomDns
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
Configuration for an arbitrary DNS provider.
Instance Attribute Summary collapse
-
#ds_records ⇒ Array<Google::Apis::DomainsV1beta1::DsRecord>
The list of DS records for this domain, which are used to enable DNSSEC.
-
#name_servers ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomDns
constructor
A new instance of CustomDns.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomDns
Returns a new instance of CustomDns.
434 435 436 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ds_records ⇒ Array<Google::Apis::DomainsV1beta1::DsRecord>
The list of DS records for this domain, which are used to enable DNSSEC. The
domain's DNS provider can provide the values to set here. If this field is
empty, DNSSEC is disabled.
Corresponds to the JSON property dsRecords
425 426 427 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 425 def ds_records @ds_records end |
#name_servers ⇒ Array<String>
Required. A list of name servers that store the DNS zone for this domain. Each
name server is a domain name, with Unicode domain names expressed in Punycode
format.
Corresponds to the JSON property nameServers
432 433 434 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 432 def name_servers @name_servers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
439 440 441 442 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 439 def update!(**args) @ds_records = args[:ds_records] if args.key?(:ds_records) @name_servers = args[:name_servers] if args.key?(:name_servers) end |