Class: Google::Apis::DomainsV1beta1::DomainForwarding
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::DomainForwarding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
Domain forwarding configuration.
Instance Attribute Summary collapse
-
#path_forwarding ⇒ Boolean
(also: #path_forwarding?)
If true, forwards the path after the domain name to the same path at the new address.
-
#pem_certificate ⇒ String
The PEM-encoded certificate chain.
-
#redirect_type ⇒ String
The redirect type.
-
#ssl_enabled ⇒ Boolean
(also: #ssl_enabled?)
If true, the forwarding works also over HTTPS.
-
#subdomain ⇒ String
The subdomain of the registered domain that is being forwarded.
-
#target_uri ⇒ String
The target of the domain forwarding, i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainForwarding
constructor
A new instance of DomainForwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainForwarding
Returns a new instance of DomainForwarding.
575 576 577 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path_forwarding ⇒ Boolean Also known as: path_forwarding?
If true, forwards the path after the domain name to the same path at the new
address.
Corresponds to the JSON property pathForwarding
543 544 545 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 543 def path_forwarding @path_forwarding end |
#pem_certificate ⇒ String
The PEM-encoded certificate chain.
Corresponds to the JSON property pemCertificate
549 550 551 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 549 def pem_certificate @pem_certificate end |
#redirect_type ⇒ String
The redirect type.
Corresponds to the JSON property redirectType
554 555 556 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 554 def redirect_type @redirect_type end |
#ssl_enabled ⇒ Boolean Also known as: ssl_enabled?
If true, the forwarding works also over HTTPS.
Corresponds to the JSON property sslEnabled
559 560 561 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 559 def ssl_enabled @ssl_enabled end |
#subdomain ⇒ String
The subdomain of the registered domain that is being forwarded. E.g. www.
example.com, example.com (i.e. the registered domain itself) or *.example.
com (i.e. all subdomains).
Corresponds to the JSON property subdomain
567 568 569 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 567 def subdomain @subdomain end |
#target_uri ⇒ String
The target of the domain forwarding, i.e. the path to redirect the subdomain
to.
Corresponds to the JSON property targetUri
573 574 575 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 573 def target_uri @target_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
580 581 582 583 584 585 586 587 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 580 def update!(**args) @path_forwarding = args[:path_forwarding] if args.key?(:path_forwarding) @pem_certificate = args[:pem_certificate] if args.key?(:pem_certificate) @redirect_type = args[:redirect_type] if args.key?(:redirect_type) @ssl_enabled = args[:ssl_enabled] if args.key?(:ssl_enabled) @subdomain = args[:subdomain] if args.key?(:subdomain) @target_uri = args[:target_uri] if args.key?(:target_uri) end |