Class: Google::Apis::DomainsV1beta1::GeoPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb

Overview

ResourceRecordSet data for one geo location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeoPolicyItem

Returns a new instance of GeoPolicyItem.



789
790
791
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DomainsV1beta1::HealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



768
769
770
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 768

def health_checked_targets
  @health_checked_targets
end

#locationString

The geo-location granularity is a GCP region. This location string should correspond to a GCP region. e.g. "us-east1", "southamerica-east1", "asia-east1" , etc. Corresponds to the JSON property location

Returns:

  • (String)


775
776
777
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 775

def location
  @location
end

#rrdataArray<String>

Corresponds to the JSON property rrdata

Returns:

  • (Array<String>)


780
781
782
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 780

def rrdata
  @rrdata
end

#signature_rrdataArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdata

Returns:

  • (Array<String>)


787
788
789
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 787

def signature_rrdata
  @signature_rrdata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



794
795
796
797
798
799
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 794

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @location = args[:location] if args.key?(:location)
  @rrdata = args[:rrdata] if args.key?(:rrdata)
  @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata)
end