Class: Google::Apis::DomainsV1beta1::GoogleDomainsDns
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::GoogleDomainsDns
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
Deprecated: For more information, see Cloud Domains feature deprecation.
Configuration for using the free DNS zone provided by Google Domains as a
Registration's dns_provider. You cannot configure the DNS zone itself using
the API. To configure the DNS zone, go to Google Domains.
Instance Attribute Summary collapse
-
#ds_records ⇒ Array<Google::Apis::DomainsV1beta1::DsRecord>
Output only.
-
#ds_state ⇒ String
Required.
-
#name_servers ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDomainsDns
constructor
A new instance of GoogleDomainsDns.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDomainsDns
Returns a new instance of GoogleDomainsDns.
863 864 865 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ds_records ⇒ Array<Google::Apis::DomainsV1beta1::DsRecord>
Output only. The list of DS records published for this domain. The list is
automatically populated when ds_state is DS_RECORDS_PUBLISHED, otherwise
it remains empty.
Corresponds to the JSON property dsRecords
847 848 849 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 847 def ds_records @ds_records end |
#ds_state ⇒ String
Required. The state of DS records for this domain. Used to enable or disable
automatic DNSSEC.
Corresponds to the JSON property dsState
853 854 855 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 853 def ds_state @ds_state end |
#name_servers ⇒ Array<String>
Output only. A list of name servers that store the DNS zone for this domain.
Each name server is a domain name, with Unicode domain names expressed in
Punycode format. This field is automatically populated with the name servers
assigned to the Google Domains DNS zone.
Corresponds to the JSON property nameServers
861 862 863 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 861 def name_servers @name_servers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
868 869 870 871 872 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 868 def update!(**args) @ds_records = args[:ds_records] if args.key?(:ds_records) @ds_state = args[:ds_state] if args.key?(:ds_state) @name_servers = args[:name_servers] if args.key?(:name_servers) end |