Class: Google::Apis::DomainsV1beta1::HealthCheckTargets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb

Overview

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckTargets

Returns a new instance of HealthCheckTargets.



902
903
904
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_endpointsArray<String>

The Internet IP addresses to be health checked. The format matches the format of ResourceRecordSet.rrdata as defined in RFC 1035 (section 5) and RFC 1034 ( section 3.6.1) Corresponds to the JSON property externalEndpoints

Returns:

  • (Array<String>)


895
896
897
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 895

def external_endpoints
  @external_endpoints
end

#internal_load_balancerArray<Google::Apis::DomainsV1beta1::LoadBalancerTarget>

Configuration for internal load balancers to be health checked. Corresponds to the JSON property internalLoadBalancer



900
901
902
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 900

def internal_load_balancer
  @internal_load_balancer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



907
908
909
910
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 907

def update!(**args)
  @external_endpoints = args[:external_endpoints] if args.key?(:external_endpoints)
  @internal_load_balancer = args[:internal_load_balancer] if args.key?(:internal_load_balancer)
end