Class: Google::Apis::DomainsV1beta1::RrSetRoutingPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb

Overview

A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicy

Returns a new instance of RrSetRoutingPolicy.



1682
1683
1684
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geoGoogle::Apis::DomainsV1beta1::GeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geo



1649
1650
1651
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1649

def geo
  @geo
end

#geo_policyGoogle::Apis::DomainsV1beta1::GeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geoPolicy



1655
1656
1657
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1655

def geo_policy
  @geo_policy
end

#health_checkString

The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy. Format this URL like https://www.googleapis.com/compute/v1/projects/project/ global/healthChecks/healthCheck`. https://cloud.google.com/compute/docs/ reference/rest/v1/healthChecks Corresponds to the JSON propertyhealthCheck`

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1663

def health_check
  @health_check
end

#primary_backupGoogle::Apis::DomainsV1beta1::PrimaryBackupPolicy

Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy. Corresponds to the JSON property primaryBackup



1670
1671
1672
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1670

def primary_backup
  @primary_backup
end

#wrrGoogle::Apis::DomainsV1beta1::WrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrr



1675
1676
1677
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1675

def wrr
  @wrr
end

#wrr_policyGoogle::Apis::DomainsV1beta1::WrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrrPolicy



1680
1681
1682
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1680

def wrr_policy
  @wrr_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1687
1688
1689
1690
1691
1692
1693
1694
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1687

def update!(**args)
  @geo = args[:geo] if args.key?(:geo)
  @geo_policy = args[:geo_policy] if args.key?(:geo_policy)
  @health_check = args[:health_check] if args.key?(:health_check)
  @primary_backup = args[:primary_backup] if args.key?(:primary_backup)
  @wrr = args[:wrr] if args.key?(:wrr)
  @wrr_policy = args[:wrr_policy] if args.key?(:wrr_policy)
end