Class: Google::Apis::DomainsV1beta1::TransferParameters
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::TransferParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
Deprecated: For more information, see Cloud Domains feature deprecation. Parameters required to transfer a domain from another registrar.
Instance Attribute Summary collapse
-
#current_registrar ⇒ String
The registrar that currently manages the domain.
-
#current_registrar_uri ⇒ String
The URL of the registrar that currently manages the domain.
-
#domain_name ⇒ String
The domain name.
-
#name_servers ⇒ Array<String>
The name servers that currently store the configuration of the domain.
-
#supported_privacy ⇒ Array<String>
Contact privacy options that the domain supports.
-
#transfer_lock_state ⇒ String
Indicates whether the domain is protected by a transfer lock.
-
#yearly_price ⇒ Google::Apis::DomainsV1beta1::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferParameters
constructor
A new instance of TransferParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferParameters
Returns a new instance of TransferParameters.
2424 2425 2426 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_registrar ⇒ String
The registrar that currently manages the domain.
Corresponds to the JSON property currentRegistrar
2390 2391 2392 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2390 def current_registrar @current_registrar end |
#current_registrar_uri ⇒ String
The URL of the registrar that currently manages the domain.
Corresponds to the JSON property currentRegistrarUri
2395 2396 2397 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2395 def current_registrar_uri @current_registrar_uri end |
#domain_name ⇒ String
The domain name. Unicode domain names are expressed in Punycode format.
Corresponds to the JSON property domainName
2400 2401 2402 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2400 def domain_name @domain_name end |
#name_servers ⇒ Array<String>
The name servers that currently store the configuration of the domain.
Corresponds to the JSON property nameServers
2405 2406 2407 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2405 def name_servers @name_servers end |
#supported_privacy ⇒ Array<String>
Contact privacy options that the domain supports.
Corresponds to the JSON property supportedPrivacy
2410 2411 2412 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2410 def supported_privacy @supported_privacy end |
#transfer_lock_state ⇒ String
Indicates whether the domain is protected by a transfer lock. For a transfer
to succeed, this must show UNLOCKED. To unlock a domain, go to its current
registrar.
Corresponds to the JSON property transferLockState
2417 2418 2419 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2417 def transfer_lock_state @transfer_lock_state end |
#yearly_price ⇒ Google::Apis::DomainsV1beta1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property yearlyPrice
2422 2423 2424 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2422 def yearly_price @yearly_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2429 2430 2431 2432 2433 2434 2435 2436 2437 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2429 def update!(**args) @current_registrar = args[:current_registrar] if args.key?(:current_registrar) @current_registrar_uri = args[:current_registrar_uri] if args.key?(:current_registrar_uri) @domain_name = args[:domain_name] if args.key?(:domain_name) @name_servers = args[:name_servers] if args.key?(:name_servers) @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy) @transfer_lock_state = args[:transfer_lock_state] if args.key?(:transfer_lock_state) @yearly_price = args[:yearly_price] if args.key?(:yearly_price) end |