Class: Google::Apis::DomainsV1beta1::WrrPolicyItem
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::WrrPolicyItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
A routing block which contains the routing information for one WRR item.
Instance Attribute Summary collapse
-
#health_checked_targets ⇒ Google::Apis::DomainsV1beta1::HealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries.
-
#rrdata ⇒ Array<String>
Corresponds to the JSON property
rrdata. -
#signature_rrdata ⇒ Array<String>
DNSSEC generated signatures for all the
rrdatawithin this item. -
#weight ⇒ Float
The weight corresponding to this
WrrPolicyItemobject.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WrrPolicyItem
constructor
A new instance of WrrPolicyItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WrrPolicyItem
Returns a new instance of WrrPolicyItem.
2475 2476 2477 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_checked_targets ⇒ Google::Apis::DomainsV1beta1::HealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to
Routing Policy queries. Only the healthy endpoints will be included in the
response. Set either internal_load_balancer or external_endpoints. Do not
set both.
Corresponds to the JSON property healthCheckedTargets
2453 2454 2455 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2453 def health_checked_targets @health_checked_targets end |
#rrdata ⇒ Array<String>
Corresponds to the JSON property rrdata
2458 2459 2460 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2458 def rrdata @rrdata end |
#signature_rrdata ⇒ Array<String>
DNSSEC generated signatures for all the rrdata within this item. When using
health-checked targets for DNSSEC-enabled zones, you can only use at most one
health-checked IP address per item.
Corresponds to the JSON property signatureRrdata
2465 2466 2467 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2465 def signature_rrdata @signature_rrdata end |
#weight ⇒ Float
The weight corresponding to this WrrPolicyItem object. When multiple
WrrPolicyItem objects are configured, the probability of returning an
WrrPolicyItem object's data is proportional to its weight relative to the sum
of weights configured for all items. This weight must be non-negative.
Corresponds to the JSON property weight
2473 2474 2475 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2473 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2480 2481 2482 2483 2484 2485 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2480 def update!(**args) @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets) @rrdata = args[:rrdata] if args.key?(:rrdata) @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata) @weight = args[:weight] if args.key?(:weight) end |