Class: Google::Apis::DomainsV1beta1::GeoPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::GeoPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Instance Attribute Summary collapse
-
#enable_fencing ⇒ Boolean
(also: #enable_fencing?)
Without fencing, if health check fails for all configured items in the current geo bucket, we failover to the next nearest geo bucket.
-
#item ⇒ Array<Google::Apis::DomainsV1beta1::GeoPolicyItem>
The primary geo routing configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GeoPolicy
constructor
A new instance of GeoPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GeoPolicy
Returns a new instance of GeoPolicy.
739 740 741 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_fencing ⇒ Boolean Also known as: enable_fencing?
Without fencing, if health check fails for all configured items in the current
geo bucket, we failover to the next nearest geo bucket. With fencing, if
health checking is enabled, as long as some targets in the current geo bucket
are healthy, we return only the healthy targets. However, if all targets are
unhealthy, we don't failover to the next nearest bucket; instead, we return
all the items in the current bucket even when all targets are unhealthy.
Corresponds to the JSON property enableFencing
730 731 732 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 730 def enable_fencing @enable_fencing end |
#item ⇒ Array<Google::Apis::DomainsV1beta1::GeoPolicyItem>
The primary geo routing configuration. If there are multiple items with the
same location, an error is returned instead.
Corresponds to the JSON property item
737 738 739 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 737 def item @item end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
744 745 746 747 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 744 def update!(**args) @enable_fencing = args[:enable_fencing] if args.key?(:enable_fencing) @item = args[:item] if args.key?(:item) end |