Class: Google::Apis::DomainsV1beta1::LoadBalancerTarget
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::LoadBalancerTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
The configuration for an individual load balancer to health check.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The frontend IP address of the load balancer to health check.
-
#ip_protocol ⇒ String
The protocol of the load balancer to health check.
-
#load_balancer_type ⇒ String
The type of load balancer specified by this target.
-
#network_url ⇒ String
The fully qualified URL of the network that the load balancer is attached to.
-
#port ⇒ String
The configured port of the load balancer.
-
#project ⇒ String
The project ID in which the load balancer is located.
-
#region ⇒ String
The region in which the load balancer is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerTarget
constructor
A new instance of LoadBalancerTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerTarget
Returns a new instance of LoadBalancerTarget.
1084 1085 1086 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The frontend IP address of the load balancer to health check.
Corresponds to the JSON property ipAddress
1045 1046 1047 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1045 def ip_address @ip_address end |
#ip_protocol ⇒ String
The protocol of the load balancer to health check.
Corresponds to the JSON property ipProtocol
1050 1051 1052 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1050 def ip_protocol @ip_protocol end |
#load_balancer_type ⇒ String
The type of load balancer specified by this target. This value must match the
configuration of the load balancer located at the LoadBalancerTarget's IP
address, port, and region. Use the following: - regionalL4ilb: for a
regional internal passthrough Network Load Balancer. - regionalL7ilb: for a
regional internal Application Load Balancer. - globalL7ilb: for a global
internal Application Load Balancer.
Corresponds to the JSON property loadBalancerType
1060 1061 1062 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1060 def load_balancer_type @load_balancer_type end |
#network_url ⇒ String
The fully qualified URL of the network that the load balancer is attached to.
This should be formatted like https://www.googleapis.com/compute/v1/projects/
project/global/networks/network`.
Corresponds to the JSON propertynetworkUrl`
1067 1068 1069 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1067 def network_url @network_url end |
#port ⇒ String
The configured port of the load balancer.
Corresponds to the JSON property port
1072 1073 1074 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1072 def port @port end |
#project ⇒ String
The project ID in which the load balancer is located.
Corresponds to the JSON property project
1077 1078 1079 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1077 def project @project end |
#region ⇒ String
The region in which the load balancer is located.
Corresponds to the JSON property region
1082 1083 1084 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1082 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1089 1090 1091 1092 1093 1094 1095 1096 1097 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1089 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) @network_url = args[:network_url] if args.key?(:network_url) @port = args[:port] if args.key?(:port) @project = args[:project] if args.key?(:project) @region = args[:region] if args.key?(:region) end |