Class: Google::Apis::DomainsV1beta1::ResourceRecordSet
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1beta1::ResourceRecordSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb
Overview
A unit of data that is returned by the DNS servers.
Instance Attribute Summary collapse
-
#name ⇒ String
For example, www.example.com.
-
#routing_policy ⇒ Google::Apis::DomainsV1beta1::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
-
#rrdata ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples.
-
#signature_rrdata ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
-
#ttl ⇒ Fixnum
Number of seconds that this
ResourceRecordSetcan be cached by resolvers. -
#type ⇒ String
The identifier of a supported record type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceRecordSet
constructor
A new instance of ResourceRecordSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceRecordSet
Returns a new instance of ResourceRecordSet.
2016 2017 2018 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
For example, www.example.com.
Corresponds to the JSON property name
1985 1986 1987 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1985 def name @name end |
#routing_policy ⇒ Google::Apis::DomainsV1beta1::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned
dynamically with the response varying based on configured properties such as
geolocation or by weighted random selection.
Corresponds to the JSON property routingPolicy
1992 1993 1994 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1992 def routing_policy @routing_policy end |
#rrdata ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see
examples.
Corresponds to the JSON property rrdata
1998 1999 2000 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 1998 def rrdata @rrdata end |
#signature_rrdata ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
Corresponds to the JSON property signatureRrdata
2003 2004 2005 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2003 def signature_rrdata @signature_rrdata end |
#ttl ⇒ Fixnum
Number of seconds that this ResourceRecordSet can be cached by resolvers.
Corresponds to the JSON property ttl
2008 2009 2010 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2008 def ttl @ttl end |
#type ⇒ String
The identifier of a supported record type. See the list of Supported DNS
record types.
Corresponds to the JSON property type
2014 2015 2016 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2014 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2021 2022 2023 2024 2025 2026 2027 2028 |
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2021 def update!(**args) @name = args[:name] if args.key?(:name) @routing_policy = args[:routing_policy] if args.key?(:routing_policy) @rrdata = args[:rrdata] if args.key?(:rrdata) @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) end |