Class: Google::Apis::DomainsV1beta1::TransferParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1beta1/classes.rb,
lib/google/apis/domains_v1beta1/representations.rb,
lib/google/apis/domains_v1beta1/representations.rb

Overview

Deprecated: For more information, see Cloud Domains feature deprecation. Parameters required to transfer a domain from another registrar.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferParameters

Returns a new instance of TransferParameters.



2416
2417
2418
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_registrarString

The registrar that currently manages the domain. Corresponds to the JSON property currentRegistrar

Returns:

  • (String)


2382
2383
2384
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2382

def current_registrar
  @current_registrar
end

#current_registrar_uriString

The URL of the registrar that currently manages the domain. Corresponds to the JSON property currentRegistrarUri

Returns:

  • (String)


2387
2388
2389
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2387

def current_registrar_uri
  @current_registrar_uri
end

#domain_nameString

The domain name. Unicode domain names are expressed in Punycode format. Corresponds to the JSON property domainName

Returns:

  • (String)


2392
2393
2394
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2392

def domain_name
  @domain_name
end

#name_serversArray<String>

The name servers that currently store the configuration of the domain. Corresponds to the JSON property nameServers

Returns:

  • (Array<String>)


2397
2398
2399
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2397

def name_servers
  @name_servers
end

#supported_privacyArray<String>

Contact privacy options that the domain supports. Corresponds to the JSON property supportedPrivacy

Returns:

  • (Array<String>)


2402
2403
2404
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2402

def supported_privacy
  @supported_privacy
end

#transfer_lock_stateString

Indicates whether the domain is protected by a transfer lock. For a transfer to succeed, this must show UNLOCKED. To unlock a domain, go to its current registrar. Corresponds to the JSON property transferLockState

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2409

def transfer_lock_state
  @transfer_lock_state
end

#yearly_priceGoogle::Apis::DomainsV1beta1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property yearlyPrice



2414
2415
2416
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2414

def yearly_price
  @yearly_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/google/apis/domains_v1beta1/classes.rb', line 2421

def update!(**args)
  @current_registrar = args[:current_registrar] if args.key?(:current_registrar)
  @current_registrar_uri = args[:current_registrar_uri] if args.key?(:current_registrar_uri)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @name_servers = args[:name_servers] if args.key?(:name_servers)
  @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy)
  @transfer_lock_state = args[:transfer_lock_state] if args.key?(:transfer_lock_state)
  @yearly_price = args[:yearly_price] if args.key?(:yearly_price)
end